@@ -27,7 +27,7 @@
 
 ;;; Code:
 
-(require 'gptel)
+(require 'gptel-request)
 (require 'cl-lib)
 (require 'project)
 
@@ -806,11 +806,11 @@ If non-nil, indicates backward movement.")
                              (overlay-get ov 'gptel-context)))
                           (overlays-in (point-min) (point-max))))))
     (mapc #'gptel-context-remove deletion-marks)
-    ;; FIXME(context): This should run in the buffer from which the context
-    ;; inspection buffer was visited.
-    ;; Update contexts and revert buffer (#482)
-    (setq gptel-context (gptel-context--collect))
     (revert-buffer))
+  ;; FIXME(context): This should run in the buffer from which the context
+  ;; inspection buffer was visited.
+  ;; Update contexts and revert buffer (#482)
+  (setq gptel-context (gptel-context--collect))
   (gptel-context-quit))
 
 (provide 'gptel-context)
